
********************************************************************
*     Replicating Schmidt-Catran/Spiess, ASR 2016 (SCS)
*       Katrin Auspurg, Josef Brüderl & Thomas Woehler
*            Last update: October 23, 2018	
*                  STATE LEVEL ANALYSIS
********************************************************************

* Based on syntax and regional data kindly made available by SCS!


version 15.0
set more off
capture log close

* Defining paths (adapt to your system!)
local path "    "                                   // your main  path
global adata 	`""`path'\Allbus""'       		    // Allbus Data
global data 	`""`path'\Laender\Data""'        	// Working directory  
global output	`""`path'\Laender\Output""'  	    // Output directory

* Opening Log-File
cd $output
log using 1_Prepare_Data.log, replace



********************************************************************************
***************************************************************************
* §1 Prepare GGSS Data (Allbus Data) 
***************************************************************************
********************************************************************************

cd $adata
use "ZA4576_v1-0-0.dta", clear
rename *, lower  // all variable names should have lower cases only


** Keep variables for analyses   
keep v1 v2 v4 v5 v6 v19 v205 v206 ///
  v552 v554 v556 v563 v564 v566 v567 v568 v569 v583 v584 v585 v607 ///
  v687 v704 v707 v710 v711 v712 v728 v723 v722 v737 v832 /// 
  v1065 v1108 v1110 v1111 v1112 v1113 v1114 v1081 v1190 v1194 v1563 /// 
  v1564 v1565 v1566 v1567 v1568 v1072
  
* Respondent identifier
rename v4        PersId
label variable   PersId "Respondent ID"


***************************************************************************
* Sample selection
***************************************************************************

* Only the four waves used by SCS
keep if v2 == 1994 | v2 == 2000 | v2 == 2004 | v2 == 2010 

* Exclude Non-Natives from the data file
keep if v6 == 1 & v1072 == 1   // German citizen and born in Germany



**************************************************************************
* Level Variables: Year and Region
**************************************************************************

* Survey year
rename v2 year
label variable year "Survey Year"
lab define year 1994 "1994" 2000 "2000" 2004 "2004" 2010 "2010"
lab val year year

* Generate year dummies
tab year, gen(year_)
rename year_2 y2000
rename year_3 y2004
rename year_4 y2010

* ROR identifier
gen    id_ror=1

* Federal state identifier (codes as used in data of federal statistical office)
recode v1108 (10=16 "Schleswig-Holstein") (20=1 "Hamburg") (30=2 "Lower Saxony") ///
             (40=3 "Bremen") (50=4 "North Rhine Westpha.") (60=5 "Hesse") (70=6 "Rhineland Palatine") ///
             (80=7 "Baden-Wuerttemberg") (90=8 "Bavaria") (100=9 "Saarland") (111 112=10 "Berlin") ///
             (120=11 "Brandenburg") (130=12 "Meckelenb.-Vorpommern") (140=13 "Saxony") ///
             (150=14 "Saxony-Anhalt") (160=15 "Thuringia"), gen(id_bdl)
label variable   id_bdl "State ID"

* Dummy for Berlin (this federal state should be excluded in some analyses)
gen berlin = id_bdl == 10  
lab var berlin "Berlin (1=yes)"

* East-West dummy
recode   v5 2=0, gen(west)
gen      east = 1-west
lab var west "Region of Interview: West Germany"
lab var east "Region of Interview: East Germany"

tab id_bdl west    //note that in Berlin we have both East and West Germans
* One therefore could argue that one should exclude Berlin from the analysis
* because we have only macrodata for the whole of Berlin. However, we follow
* SCS here and leave Berlin in the analysis and differentiate East/West by the
* East-West dummy


******************************************************************************
* Dependent Variable: Attitudes regarding welfare spending
*                     Higher values indicate support for more welfare
******************************************************************************
tab v205 v206, nol

drop if v206 == 9		    // drop if dependent variable == missing

* Version 1 used by SCS: respondents with "no opinion" are coded to the middle category "should stay the same"
clonevar          morewel = v206
replace           morewel = 2      if v205 == 2      // respondents with "no opinion"
label variable    morewel "Government should increase social spending"

* Version 2 used for robustness check: "no opinion" recoded as missing
clonevar          morewel_smallN = v206
replace           morewel_smallN = .     if morewel_smallN==0
label variable    morewel_smallN "Government should increase spending (small N)"

tab1 morewel morewel_smallN      // N = 10,645


******************************************************************************
* Controls
******************************************************************************

* Gender
recode v556 2=0
rename v556 male
label variable male "Gender(male=1)"

* Age
rename v554 age
drop if age == 999                        		// age==missing dropped
label variable age "Age"
gen agesq = age^2
label variable agesq "Age squared"
	
* Married
recode v737 2/6 = 0 
rename v737 married
drop if married == 99      				 		// married==missing dropped
label variable married "Family status = married"

* Education
recode v563 (1 2 = 1) (3 = 2) (4 5 = 3) (else=4)
rename v563 educ
drop if educ == 4   							//"other", "still at school", "missing" dropped
label variable educ "Highest educational degree"
label define educlb 1"no educ/volks/hauptschule" 2"mittlere Reife" 3"(Fach)Hochschulreife"
label values educ educlb
tab educ, gen(educ_)
rename educ_1 primary
rename educ_2 lower_secondary
rename educ_3 higher_secondary
	
* Employment Status
drop if v583 == 99                 				// missing dropped
gen emplstat = 1 if v583 < 3
replace emplstat = 1  if v583 == 12
replace emplstat = 2 if v584 == 3
replace emplstat = 3 if v583 == 3 & emplstat==. | v583 == 4 & emplstat == .
label variable emplstat "Employment Status"
label define emplstatlb 1"Employed" 2"Unemplyoed" 3"Not in labor force"
label values emplstat emplstatlb
tab emplstat, gen(empl_)
rename empl_1 employed
rename empl_2 unemployed
rename empl_3 nilf
	
* Income
rename v707 income_ind
label variable income_ind "Individual net income"
recode income_ind 99997 99999= .

rename v712 income_hh
	label variable income_hh "Household net income"
	drop if income_hh >= 99997              		// missing dropped
rename v1190 hhmembers
	label variable hhmembers "Number of household members"
	drop if hhmembers == 99                 		// missing dropped
	gen hhmembers_sqrt = sqrt(hhmembers)

gen income_hh_equiv = income_hh/(sqrt(hhmembers)*1000)
	label variable income_hh_equiv "Equivalized household inome in 1000 Euros"
	
* Left-Right
rename v19 leftright
label variable leftright "Left-Right position"
drop if leftright == 99       						 // missing dropped
	
* Community size
rename v1110 comsize
label variable comsize "Community size"
recode comsize (0 = 10)       // to get identical reference category to SCS
tab comsize, gen(comsize_)
drop if comsize == 9          						 // missing dropped

tab comsize      // N = 8,245


*************************************************************************
* Save prepared Allbus data	
*************************************************************************
order PersId year id_bdl id_ror berlin v5 v6 morewel male age married educ primary lower_secon higher_s /// 
      emplstat employed unemployed nilf leftright income_* comsize comsize_1-comsize_7 v1565

keep PersId year y2000 y2004 y2010 id_bdl id_ror berlin v5 v6 v205 v206 morewel morewel_smallN east west /// 
  male age married educ primary lower_secon higher_s emplstat employed unemployed nilf ///
  leftright income_* comsize comsize_1-comsize_7  v552 v1081  
  
cd $data
save allbus_prep, replace 



********************************************************************************
***************************************************************************
* §2 Prepare and save macrodata
***************************************************************************
********************************************************************************
cd $data
use macrodata_laender.dta, clear
* use macrodata_laender_SCS.dta, clear   // these are SCS's original data (including the data error!!)

* rename unemplro unemplr   // only needed if SCS original data are used
* rename foreigno foreign
* rename gdppco gdppc

tab id_bdl year     // we have macro information for each state-year

* Interaction terms foreigners and unemployment rates (as SCS do it)
gen    ia_foreign_unemplr    =     foreign * unemplr		
gen    foreign_sq            =     foreign^2
gen    ia_foreign_sq_unemplr =     foreign_sq * unemplr


* Contrary to SCS we de-mean on the regional level!!
foreach var of varlist foreign unemplr gdppc foreign_sq ia_foreign_unemplr ia_foreign_sq_unemplr {
  bys id_bdl: egen `var'_m = mean(`var')         // regional mean
  gen `var'_dm = `var' - `var'_m                 // de-meaning
}

save macrodata_laender_prep, replace


********************************************************************************
***************************************************************************
* §3 Merge macrodata to Allbus data
***************************************************************************
********************************************************************************
cd $data
use allbus_prep, clear 
merge n:1 id_bdl year using macrodata_laender_prep 
drop _merge 

* Numbering the state-years 
bysort id_bdl   year: gen nr = _n
bysort id_bdl   year: gen n_cases = _N

tab n_cases if nr==1

gen region = id_bdl                          // Variable to identify level 2 


save data_complete, replace           // N = 8,245



*****************************************************************************
log close

		
