
********************************************************************
*     Replicating Schmidt-Catran/Spiess, ASR 2016 (SCS)
*       Katrin Auspurg, Josef Brüderl & Thomas Woehler
*            Last update: November 15, 2018	
*                  ROR LEVEL ANALYSIS
********************************************************************

* Based on syntax and regional data kindly made available by SCS!


version 15.0
set more off
capture log close

* Defining paths (adapt to your system!)
local path "    "                                   // your main  path
global adata 	`""`path'\Allbus""'       		    // Allbus Data
global data 	`""`path'\ROR\Data""'        	    // Working directory  
global output	`""`path'\ROR\Output""'  	        // Output directory

* Opening Log-File
cd $output
log using 3_Regressions.log, replace


* Opening data
cd $data
use data_complete, clear
cd $output

* Defining locals for the sets of variables used in the models
local controls "male age married primary higher_secondary employed unemployed leftright income_hh_equiv i.comsize" // control variables
local context  "foreign_m foreign_dm unemplr_m unemplr_dm gdppc_m gdppc_dm"     // context variables


**********************************************************************************
**                   TABLE 1 / B2: main results
**********************************************************************************

******* Models 1: SCS replication (Models 2 - 4 in their Table 2) ************
* Deviations from SCS: a) we de-mean on the regional level, 
*                      b) cutpoints differ because our reference is "west"

* Model 1a: only main effect
meglm  morewel  `controls'  `context'  i.east i.year  ///
       || region: || year:, link(probit) fam(ordinal) diff
est store m1a

* Model 1b: + foreign squared
meglm  morewel  `controls'  `context'  foreign_sq_m  foreign_sq_dm  i.east i.year  ///
       || region: || year:, link(probit) fam(ordinal) diff
est store m1b

* Model 1c: + interaction foreign x unemployement
meglm  morewel  `controls'  `context'  ia_foreign_unemplr_m  ia_foreign_unemplr_dm  i.east i.year  ///
       || region: || year:, link(probit) fam(ordinal) diff
est store m1c


******* Models 2: with heterogeneous time trends ******************************

* Model 2a: only main effect
meglm  morewel  `controls'  `context'  i.east##i.year  ///
       || region: || year:, link(probit) fam(ordinal) diff
est store m2a

* Model 2b: + foreign squared
meglm  morewel  `controls'  `context'  foreign_sq_m  foreign_sq_dm  i.east##i.year  ///
       || region: || year:, link(probit) fam(ordinal) diff
est store m2b

* Model 2c: + interaction foreign x unemployement
meglm  morewel  `controls'  `context'  ia_foreign_unemplr_m  ia_foreign_unemplr_dm  i.east##i.year  ///
       || region: || year:, link(probit) fam(ordinal) diff
est store m2c

******* Models 3: without year 1994 ******************************************
preserve
drop if year == 1994
drop *_m *_dm             //de-meaning has to be done anew
foreach var of varlist foreign unemplr gdppc foreign_sq ia_foreign_unemplr {  
   bys region: egen `var'_m2 = mean(`var') if nr == 1   // using only first obs per region-year to compute region mean
   bys region: egen `var'_m =  mean(`var'_m2)           // copying value to all respondents in a region
   drop `var'_m2
   gen `var'_dm = `var' - `var'_m 
 }

* Model 3a: only main effect
meglm  morewel  `controls'  `context'  i.east i.year  ///
       || region: || year:, link(probit) fam(ordinal) diff
est store m3a

* Model 3b: + foreign squared
meglm  morewel  `controls'  `context'  foreign_sq_m  foreign_sq_dm  i.east i.year  ///
       || region: || year:, link(probit) fam(ordinal) diff
est store m3b

* Model 3c: + interaction foreign x unemployement
meglm  morewel  `controls'  `context'  ia_foreign_unemplr_m  ia_foreign_unemplr_dm  i.east i.year  ///
       || region: || year:, link(probit) fam(ordinal) diff
est store m3c

restore

esttab m1a m1b m1c m2a m2b m2c m3a m3b m3c, b(%8.4f) star se aic(%8.2f) bic(%8.2f)


* AMEs of proportion foreigner (within effect) for Model 1a
estimates restore   m1a
margins, dydx(foreign_dm)  predict(pr outcome(1))
margins, dydx(foreign_dm)  predict(pr outcome(2))
margins, dydx(foreign_dm)  predict(pr outcome(3))


**********************************************************************************
**        TABLE B1: reproducing SCS more closely
**********************************************************************************
* Models 2 - 4 in their Table 2  with de-meaning on the individual level

clonevar foreigno = foreign   // new variables to be de-meaned on individual level
clonevar unemplro = unemplr
clonevar gdppco   = gdppc
clonevar foreign_sqo = foreign_sq
clonevar ia_foreign_unemplro = ia_foreign_unemplr
foreach var of varlist foreigno unemplro gdppco foreign_sqo ia_foreign_unemplro {  // de-meaning on individual level
   bys region: egen `var'_m = mean(`var') 
   gen `var'_dm = `var' - `var'_m 
 }

local contextscs  "foreigno_m foreigno_dm unemplro_m unemplro_dm gdppco_m gdppco_dm"

meglm  morewel  `controls'  `contextscs'  i.east i.year  ///
       || region: || year:, link(probit) fam(ordinal) diff
est store m1arep
meglm  morewel  `controls'  `contextscs'  foreign_sqo_m  foreign_sqo_dm  i.east i.year  ///
       || region: || year:, link(probit) fam(ordinal) diff
est store m1brep
meglm  morewel  `controls'  `contextscs'  ia_foreign_unemplro_m  ia_foreign_unemplro_dm  i.east i.year  ///
       || region: || year:, link(probit) fam(ordinal) diff
est store m1crep

esttab m1arep m1brep m1crep, b(%8.4f) star se aic(%8.2f) bic(%8.2f)


**********************************************************************************
**       TABLE D1: less restricted sample and "no opinion" on morewel excluded
**********************************************************************************

cd $data
preserve
use data_complete_largeN, clear    // data include ROR-years with less than 10 respondents

* Models 1a - 1c: SCS specification
meglm  morewel_smallN  `controls'  `context'  i.east i.year  /// outcome variable excludes "no opinion"
       || region: || year:, link(probit) fam(ordinal) diff
est store m1ar
meglm  morewel_smallN  `controls'  `context'  foreign_sq_m  foreign_sq_dm  i.east i.year  ///
       || region: || year:, link(probit) fam(ordinal) diff
est store m1br
meglm  morewel_smallN  `controls'  `context'  ia_foreign_unemplr_m  ia_foreign_unemplr_dm  i.east i.year  ///
       || region: || year:, link(probit) fam(ordinal) diff
est store m1cr

* Models 2a - 2c: heterogeneous time trends
meglm  morewel_smallN  `controls'  `context'  i.east##i.year  ///
       || region: || year:, link(probit) fam(ordinal) diff
est store m2ar
meglm  morewel_smallN  `controls'  `context'  foreign_sq_m  foreign_sq_dm  i.east##i.year  ///
       || region: || year:, link(probit) fam(ordinal) diff
est store m2br
meglm  morewel_smallN  `controls'  `context'  ia_foreign_unemplr_m  ia_foreign_unemplr_dm  i.east##i.year  ///
       || region: || year:, link(probit) fam(ordinal) diff
est store m2cr
restore 

* Models 3a - 3c: without year 1994
preserve
use data_complete_largeN, clear    // data include ROR-years with less than 10 respondents
drop if year == 1994
drop *_m *_dm             //de-meaning has to be done anew
foreach var of varlist foreign unemplr gdppc foreign_sq ia_foreign_unemplr {  
   bys region: egen `var'_m2 = mean(`var') if nr == 1   // using only first obs per region-year to compute region mean
   bys region: egen `var'_m =  mean(`var'_m2)           // copying value to all respondents in a region
   drop `var'_m2
   gen `var'_dm = `var' - `var'_m 
 }
meglm  morewel_smallN  `controls'  `context'  i.east i.year  /// outcome variable excludes "no opinion"
       || region: || year:, link(probit) fam(ordinal) diff
est store m3ar
meglm  morewel_smallN  `controls'  `context'  foreign_sq_m  foreign_sq_dm  i.east i.year  ///
       || region: || year:, link(probit) fam(ordinal) diff
est store m3br
meglm  morewel_smallN  `controls'  `context'  ia_foreign_unemplr_m  ia_foreign_unemplr_dm  i.east i.year  ///
       || region: || year:, link(probit) fam(ordinal) diff
est store m3cr
restore

esttab m1ar m1br m1cr m2ar m2br m2cr m3ar m3br m3cr, b(%8.4f) star se aic(%8.2f) bic(%8.2f)

cd $output


**********************************************************************************
**       TABLE D2: alternative specification of moderator effects
**********************************************************************************

******* Models 1: without heterogeneous time trends
meglm  morewel  `controls'  `context'  c.foreign_m#c.foreign_dm  i.east i.year  /// + foreign_m x foreign
       || region: || year:, link(probit) fam(ordinal) diff
est store m1bmod
meglm  morewel  `controls'  `context'  c.unemplr_m#c.foreign_dm  i.east i.year  /// + unemployement_m x foreign
       || region: || year:, link(probit) fam(ordinal) diff
est store m1cmod

******* Models 2: with heterogeneous time trends
meglm  morewel  `controls'  `context'  c.foreign_m#c.foreign_dm  i.east##i.year  /// + foreign_m x foreign
       || region: || year:, link(probit) fam(ordinal) diff
est store m2bmod
meglm  morewel  `controls'  `context'  c.unemplr_m#c.foreign_dm  i.east##i.year  /// + unemployement_m x foreign
       || region: || year:, link(probit) fam(ordinal) diff
est store m2cmod

******* Models 3: without year 1994
preserve
drop if year == 1994
drop *_m *_dm             //de-meaning has to be done anew
foreach var of varlist foreign unemplr gdppc {  
   bys region: egen `var'_m2 = mean(`var') if nr == 1   // using only first obs per region-year to compute region mean
   bys region: egen `var'_m =  mean(`var'_m2)           // copying value to all respondents in a region
   drop `var'_m2
   gen `var'_dm = `var' - `var'_m 
 }

meglm  morewel  `controls'  `context'  c.foreign_m#c.foreign_dm  i.east i.year  /// + foreign_m x foreign
       || region: || year:, link(probit) fam(ordinal) diff
est store m3bmod
margins, dydx(foreign_dm) at(foreign_m=(1.4 2 3 4 5.5 7 8 9.5 10 11.5 13 14 15 16.9)) predict(pr outcome(3)) // plotting with observed range
marginsplot, yline(0) recast(line) recastci(rarea) ciopt(color(%50))            ///
  ylabels(-0.2 "-20" -0.15 "-15" -0.10 "-10" -0.05 "-5" 0 "0" 0.05 "5" 0.10 "10") ytitle("Marginal effects (ppts)") ///
  xlabels(0"0" 5"5" 10"10" 15"15" 20"20") xtitle("Proportion foreigners (%)")  ///
  title("w/o year 1994") name(Fig_C1_A3, replace) 

meglm  morewel  `controls'  `context'  c.unemplr_m#c.foreign_dm  i.east i.year  /// + unemployement_m x foreign
       || region: || year:, link(probit) fam(ordinal) diff
est store m3cmod
margins, dydx(foreign_dm) at(unemplr_m=(5.2 6.5 7 8 9.5 11 12.5 14 15.5 16 17 19 20.9)) predict(pr outcome(3)) // plotting with observed range
marginsplot, yline(0) recast(line) recastci(rarea) ciopt(color(%50))                    ///
  ylabels(-0.3 "-30" -0.25 "-25" -0.2 "-20" -0.15 "-15" -0.10 "-10" -0.05 "-5" 0 "0" 0.05 "5" 0.10 "10") ytitle("Marginal effects (ppts)") ///  xlabels(0"0" 5"5" 10"10" 15"15" 20"20" 25"25") xtitle("Proportion unemployed (%)")  ///   title("w/o year 1994") name(Fig_C1_B3, replace)  

restore


esttab m1bmod m1cmod m2bmod m2cmod m3bmod m3cmod, b(%8.4f) star se aic(%8.2f) bic(%8.2f)


********************* Conditional Effect Plots *******************************

* Figure C1, Panel A 
estimates restore   m1bmod
margins, dydx(foreign_dm) at(foreign_m=(1.4 2 3 4 5.5 7 8 9.5 10 11.5 13 14 15 16.9)) predict(pr outcome(3)) // plotting with observed range
marginsplot, yline(0) recast(line) recastci(rarea) ciopt(color(%50))            ///
  ylabels(-0.2 "-20" -0.15 "-15" -0.10 "-10" -0.05 "-5" 0 "0" 0.05 "5" 0.10 "10") ytitle("Marginal effects (ppts)") ///
  xlabels(0"0" 5"5" 10"10" 15"15" 20"20") xtitle("Proportion foreigners (%)")  ///
  title("w/o heterogeneous time trends") name(Fig_C1_A1, replace) 

estimates restore   m2bmod
margins, dydx(foreign_dm) at(foreign_m=(1.4 2 3 4 5.5 7 8 9.5 10 11.5 13 14 15 16.9)) predict(pr outcome(3)) // plotting with observed range
marginsplot, yline(0) recast(line) recastci(rarea) ciopt(color(%50))            ///
  ylabels(-0.2 "-20" -0.15 "-15" -0.10 "-10" -0.05 "-5" 0 "0" 0.05 "5" 0.10 "10") ytitle("Marginal effects (ppts)") ///
  xlabels(0"0" 5"5" 10"10" 15"15" 20"20") xtitle("Proportion foreigners (%)")  ///
  title("w/ heterogeneous time trends") name(Fig_C1_A2, replace) 

graph combine Fig_C1_A1 Fig_C1_A2 Fig_C1_A3, rows(1) saving(Figure_C1_A, replace)
graph export Figure_C1_A.tif, replace width(10000)


* Figure C1, Panel B
estimates restore   m1cmod
margins, dydx(foreign_dm) at(unemplr_m=(5.2 6.5 7 8 9.5 11 12.5 14 15.5 16 17 19 20.9)) predict(pr outcome(3)) // plotting with observed range
marginsplot, 	yline(0) recast(line) recastci(rarea) ciopt(color(%50))                    ///  
				ylabels(-0.3 "-30" -0.25 "-25" -0.2 "-20" -0.15 "-15" -0.10 "-10" -0.05 "-5" 0 "0" 0.05 "5" 0.10 "10") ytitle("Marginal effects (ppts)") ///  
				xlabels(0"0" 5"5" 10"10" 15"15" 20"20" 25"25") xtitle("Proportion unemployed (%)")  ///   
				title("w/o heterogeneous time trends") name(Fig_C1_B1, replace)
  
estimates restore   m2cmod
margins, dydx(foreign_dm) at(unemplr_m=(5.2 6.5 7 8 9.5 11 12.5 14 15.5 16 17 19 20.9)) predict(pr outcome(3)) // plotting with observed range
marginsplot, 	yline(0) recast(line) recastci(rarea) ciopt(color(%50))                    ///  
				ylabels(-0.3 "-30" -0.25 "-25" -0.2 "-20" -0.15 "-15" -0.10 "-10" -0.05 "-5" 0 "0" 0.05 "5" 0.10 "10") ytitle("Marginal effects (ppts)") ///
				xlabels(0"0" 5"5" 10"10" 15"15" 20"20" 25"25%") xtitle("Proportion unemployed (%)")  ///
				title("w/ heterogeneous time trends") name(Fig_C1_B2, replace) 
  
graph combine Fig_C1_B1 Fig_C1_B2 Fig_C1_B3, rows(1) saving(Figure_C1_B, replace)
graph export Figure_C1_B.tif, replace width(10000)


           
**********************************************************************************
**     D5 in OS: separate models for East and West (main effects model only)
**********************************************************************************

* West (without Berlin)
meglm  morewel  `controls'  `context'  i.year  if east==0 & berlin~=1 ///
       || region: || year:, link(probit) fam(ordinal) diff

* East (without Berlin)
meglm  morewel  `controls'  `context'  i.year  if east==1 & berlin~=1 ///
       || region: || year:, link(probit) fam(ordinal) diff


**********************************************************************************
**     D6 in OS: Placebo-test (main effects model only)
**********************************************************************************

* number of inhabitants (in 1,000,000) as additional predictor
meglm  morewel  `controls'  `context'  inhab_m inhab_dm  i.east i.year  ///
       || region: || year:, link(probit) fam(ordinal) diff

 

 
*******************************************************************************
log close
